==> nextcloud-app-contacts-3.3.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/id.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontak",
    "All contacts" : "Semua kontak",
    "Details" : "Detil",
    "Invalid image" : "Gambar tidak sah",
    "Loading" : "Memuat",
    "Name" : "Nama",
    "Title" : "Judul",
    "Download" : "Unduh",
    "Delete" : "Hapus",
    "Cancel" : "Membatalkan",
    "Groups" : "Grup",
    "New contact" : "Kontak baru",
    "No results" : "Tidak ada hasil",
    "Last modified" : "Terakhir diubah",
    "Rename" : "Ubah nama",
    "Enabled" : "Diaktifkan",
    "Disabled" : "Dinonaktifkan",
    "Copy link" : "Salin tautan",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "can edit" : "dapat menyunting",
    "Address book name" : "Nama buku alamat",
    "First name" : "Nama depan",
    "Last name" : "Nama belakang",
    "Display name" : "Nama tampilan",
    "Not grouped" : "Tidak dikelompokkan",
    "Nickname" : "Nama panggilan",
    "Detailed name" : "Nama lengkap",
    "Additional names" : "Nama tambahan",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Notes" : "Catatan",
    "Website" : "Situs Web",
    "Location" : "Lokasi",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Depan",
    "Work" : "Kantor",
    "Other" : "Lainnya",
    "Address" : "Alamat",
    "Post office box" : "PO BOX",
    "City" : "Kota",
    "State or province" : "Provinsi",
    "Postal code" : "Kode pos",
    "Country" : "Negara",
    "Birthday" : "Tanggal lahir",
    "Anniversary" : "Ulang tahun",
    "Date of death" : "Tanggal kematian",
    "Email" : "Email",
    "Instant messaging" : "Pesan Instan",
    "Phone" : "Telpon",
    "Mobile" : "Ponsel",
    "Fax" : "Fax",
    "Fax home" : "Fax rumah",
    "Fax work" : "Fax kerja",
    "Pager" : "Pager",
    "Voice" : "Suara",
    "Social network" : "Media sosial",
    "None" : "Tidak ada",
    "Unknown" : "Tidak diketahui"
},
"nplurals=1; plural=0;");

==> nextcloud-app-contacts-3.4.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/id.js <==
OC.L10N.register(
    "contacts",
    {
    "All contacts" : "Semua kontak",
    "Details" : "Detil",
    "Contacts" : "Kontak",
    "Invalid image" : "Gambar tidak sah",
    "Name" : "Nama",
    "Title" : "Judul",
    "Download" : "Unduh",
    "Delete" : "Hapus",
    "Cancel" : "Membatalkan",
    "Groups" : "Grup",
    "New contact" : "Kontak baru",
    "No results" : "Tidak ada hasil",
    "Last modified" : "Terakhir diubah",
    "Rename" : "Ubah nama",
    "Enabled" : "Diaktifkan",
    "Disabled" : "Dinonaktifkan",
    "Copy link" : "Salin tautan",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "can edit" : "dapat menyunting",
    "Address book name" : "Nama buku alamat",
    "First name" : "Nama depan",
    "Last name" : "Nama belakang",
    "Display name" : "Nama tampilan",
    "Group name" : "Nama grup",
    "Not grouped" : "Tidak dikelompokkan",
    "Close" : "Tutup",
    "Import" : "Impor",
    "Nickname" : "Nama panggilan",
    "Detailed name" : "Nama lengkap",
    "Additional names" : "Nama tambahan",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Notes" : "Catatan",
    "Website" : "Situs Web",
    "Location" : "Lokasi",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Depan",
    "Work" : "Kantor",
    "Other" : "Lainnya",
    "Address" : "Alamat",
    "Post office box" : "PO BOX",
    "City" : "Kota",
    "State or province" : "Provinsi",
    "Postal code" : "Kode pos",
    "Country" : "Negara",
    "Birthday" : "Tanggal lahir",
    "Anniversary" : "Ulang tahun",
    "Date of death" : "Tanggal kematian",
    "Email" : "Email",
    "Instant messaging" : "Pesan Instan",
    "Phone" : "Telpon",
    "Mobile" : "Ponsel",
    "Fax" : "Fax",
    "Fax home" : "Fax rumah",
    "Fax work" : "Fax kerja",
    "Pager" : "Pager",
    "Voice" : "Suara",
    "Social network" : "Media sosial",
    "None" : "Tidak ada",
    "Unknown" : "Tidak diketahui"
},
"nplurals=1; plural=0;");
